# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_project.proto\x12\x1foak9.tython.gcp.compute_project\x1a\x13shared/shared.proto\";\n)ComputeProjectDefaultNetworkTierXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\"\xec\x01\n ComputeProjectDefaultNetworkTier\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\\\n\x08timeouts\x18\x04 \x01(\x0b\x32J.oak9.tython.gcp.compute_project.ComputeProjectDefaultNetworkTierXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"A\n\x1f\x43omputeProjectMetadataXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xcc\x02\n\x16\x43omputeProjectMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12W\n\x08metadata\x18\x02 \x03(\x0b\x32\x45.oak9.tython.gcp.compute_project.ComputeProjectMetadata.MetadataEntry\x12\x0f\n\x07project\x18\x03 \x01(\t\x12R\n\x08timeouts\x18\x04 \x01(\x0b\x32@.oak9.tython.gcp.compute_project.ComputeProjectMetadataXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#ComputeProjectMetadataItemXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe6\x01\n\x1a\x43omputeProjectMetadataItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12V\n\x08timeouts\x18\x05 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_project.ComputeProjectMetadataItemXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_project_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEPROJECTMETADATA_METADATAENTRY._options = None
  _COMPUTEPROJECTMETADATA_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEPROJECTDEFAULTNETWORKTIERXTIMEOUTS._serialized_start=87
  _COMPUTEPROJECTDEFAULTNETWORKTIERXTIMEOUTS._serialized_end=146
  _COMPUTEPROJECTDEFAULTNETWORKTIER._serialized_start=149
  _COMPUTEPROJECTDEFAULTNETWORKTIER._serialized_end=385
  _COMPUTEPROJECTMETADATAXTIMEOUTS._serialized_start=387
  _COMPUTEPROJECTMETADATAXTIMEOUTS._serialized_end=452
  _COMPUTEPROJECTMETADATA._serialized_start=455
  _COMPUTEPROJECTMETADATA._serialized_end=787
  _COMPUTEPROJECTMETADATA_METADATAENTRY._serialized_start=740
  _COMPUTEPROJECTMETADATA_METADATAENTRY._serialized_end=787
  _COMPUTEPROJECTMETADATAITEMXTIMEOUTS._serialized_start=789
  _COMPUTEPROJECTMETADATAITEMXTIMEOUTS._serialized_end=874
  _COMPUTEPROJECTMETADATAITEM._serialized_start=877
  _COMPUTEPROJECTMETADATAITEM._serialized_end=1107
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Fleet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Fleet = Fleet

@typing_extensions.final
class RoboMaker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLEET_FIELD_NUMBER: builtins.int
    ROBOT_FIELD_NUMBER: builtins.int
    ROBOT_APPLICATION_FIELD_NUMBER: builtins.int
    ROBOT_APPLICATION_VERSION_FIELD_NUMBER: builtins.int
    SIMULATION_APPLICATION_FIELD_NUMBER: builtins.int
    SIMULATION_APPLICATION_VERSION_FIELD_NUMBER: builtins.int
    @property
    def fleet(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Fleet]: ...
    @property
    def robot(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Robot]: ...
    @property
    def robot_application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RobotApplication]: ...
    @property
    def robot_application_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RobotApplicationVersion]: ...
    @property
    def simulation_application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimulationApplication]: ...
    @property
    def simulation_application_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimulationApplicationVersion]: ...
    def __init__(
        self,
        *,
        fleet: collections.abc.Iterable[global___Fleet] | None = ...,
        robot: collections.abc.Iterable[global___Robot] | None = ...,
        robot_application: collections.abc.Iterable[global___RobotApplication] | None = ...,
        robot_application_version: collections.abc.Iterable[global___RobotApplicationVersion] | None = ...,
        simulation_application: collections.abc.Iterable[global___SimulationApplication] | None = ...,
        simulation_application_version: collections.abc.Iterable[global___SimulationApplicationVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fleet", b"fleet", "robot", b"robot", "robot_application", b"robot_application", "robot_application_version", b"robot_application_version", "simulation_application", b"simulation_application", "simulation_application_version", b"simulation_application_version"]) -> None: ...

global___RoboMaker = RoboMaker

@typing_extensions.final
class Robot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FLEET_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    GREENGRASS_GROUP_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    fleet: builtins.str
    architecture: builtins.str
    greengrass_group_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        fleet: builtins.str = ...,
        architecture: builtins.str = ...,
        greengrass_group_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "fleet", b"fleet", "greengrass_group_id", b"greengrass_group_id", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Robot = Robot

@typing_extensions.final
class RobotApplicationRobotSoftwareSuite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___RobotApplicationRobotSoftwareSuite = RobotApplicationRobotSoftwareSuite

@typing_extensions.final
class RobotApplicationSourceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    architecture: builtins.str
    s3_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        architecture: builtins.str = ...,
        s3_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key"]) -> None: ...

global___RobotApplicationSourceConfig = RobotApplicationSourceConfig

@typing_extensions.final
class RobotApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    ROBOT_SOFTWARE_SUITE_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    current_revision_id: builtins.str
    @property
    def robot_software_suite(self) -> global___RobotApplicationRobotSoftwareSuite: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RobotApplicationSourceConfig]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        current_revision_id: builtins.str = ...,
        robot_software_suite: global___RobotApplicationRobotSoftwareSuite | None = ...,
        sources: collections.abc.Iterable[global___RobotApplicationSourceConfig] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_revision_id", b"current_revision_id", "name", b"name", "resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite", "sources", b"sources", "tags", b"tags"]) -> None: ...

global___RobotApplication = RobotApplication

@typing_extensions.final
class RobotApplicationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    current_revision_id: builtins.str
    application: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        current_revision_id: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "current_revision_id", b"current_revision_id", "resource_info", b"resource_info"]) -> None: ...

global___RobotApplicationVersion = RobotApplicationVersion

@typing_extensions.final
class SimulationApplicationRenderingEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___SimulationApplicationRenderingEngine = SimulationApplicationRenderingEngine

@typing_extensions.final
class SimulationApplicationSimulationSoftwareSuite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___SimulationApplicationSimulationSoftwareSuite = SimulationApplicationSimulationSoftwareSuite

@typing_extensions.final
class SimulationApplicationRobotSoftwareSuite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___SimulationApplicationRobotSoftwareSuite = SimulationApplicationRobotSoftwareSuite

@typing_extensions.final
class SimulationApplicationSourceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    architecture: builtins.str
    s3_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        architecture: builtins.str = ...,
        s3_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key"]) -> None: ...

global___SimulationApplicationSourceConfig = SimulationApplicationSourceConfig

@typing_extensions.final
class SimulationApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RENDERING_ENGINE_FIELD_NUMBER: builtins.int
    SIMULATION_SOFTWARE_SUITE_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    ROBOT_SOFTWARE_SUITE_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def rendering_engine(self) -> global___SimulationApplicationRenderingEngine: ...
    @property
    def simulation_software_suite(self) -> global___SimulationApplicationSimulationSoftwareSuite: ...
    current_revision_id: builtins.str
    @property
    def robot_software_suite(self) -> global___SimulationApplicationRobotSoftwareSuite: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimulationApplicationSourceConfig]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rendering_engine: global___SimulationApplicationRenderingEngine | None = ...,
        simulation_software_suite: global___SimulationApplicationSimulationSoftwareSuite | None = ...,
        current_revision_id: builtins.str = ...,
        robot_software_suite: global___SimulationApplicationRobotSoftwareSuite | None = ...,
        sources: collections.abc.Iterable[global___SimulationApplicationSourceConfig] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rendering_engine", b"rendering_engine", "resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite", "simulation_software_suite", b"simulation_software_suite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_revision_id", b"current_revision_id", "name", b"name", "rendering_engine", b"rendering_engine", "resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite", "simulation_software_suite", b"simulation_software_suite", "sources", b"sources", "tags", b"tags"]) -> None: ...

global___SimulationApplication = SimulationApplication

@typing_extensions.final
class SimulationApplicationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    current_revision_id: builtins.str
    application: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        current_revision_id: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "current_revision_id", b"current_revision_id", "resource_info", b"resource_info"]) -> None: ...

global___SimulationApplicationVersion = SimulationApplicationVersion



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ram.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_ram.proto\x12\x13oak9.tython.aws.ram\x1a\x13shared/shared.proto\"\x8d\x02\n\rResourceShare\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nprincipals\x18\x02 \x03(\t\x12!\n\x19\x61llow_external_principals\x18\x03 \x01(\x08\x12\x15\n\rresource_arns\x18\x04 \x03(\t\x12:\n\x04tags\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.ram.ResourceShare.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x03RAM\x12:\n\x0eresource_share\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.ram.ResourceShareb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ram_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCESHARE_TAGSENTRY._options = None
  _RESOURCESHARE_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCESHARE._serialized_start=64
  _RESOURCESHARE._serialized_end=333
  _RESOURCESHARE_TAGSENTRY._serialized_start=290
  _RESOURCESHARE_TAGSENTRY._serialized_end=333
  _RAM._serialized_start=335
  _RAM._serialized_end=400
# @@protoc_insertion_point(module_scope)
